<template>
  <div class="riskBox">
    <el-form ref="formRef" :model="state.formData" :rules="state.rules" class="register-form" label-position="top">
      <el-row :gutter="30">
        <el-col :span="6">
          <el-form-item prop="project.name" label="项目名称">
            <el-input
                v-model="state.formData.project.name"
                size="large"
                placeholder="请输入项目名称"
            >
            </el-input>
          </el-form-item>
        </el-col>
        <el-col :span="6">
          <el-form-item prop="project.client" label="委托单位">
            <el-input
                v-model="state.formData.project.client"
                size="large"
                placeholder="请输入委托单位"
            >
            </el-input>
          </el-form-item>
        </el-col>
        <el-col :span="6">
          <el-form-item prop="project.creditCode" label="委托单位统一社会信用代码">
            <el-input
                v-model="state.formData.project.creditCode"
                size="large"
                placeholder="请输入委托单位统一社会信用代码"
            >
            </el-input>
          </el-form-item>
        </el-col>
        <el-col :span="6">
          <el-form-item prop="project.address" label="详细地址">
            <el-input
                maxlength="100"
                show-word-limit
                v-model="state.formData.project.address"
                size="large"
                placeholder="请输入详细地址"
            >
            </el-input>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row :gutter="30">
        <el-col :span="6">
          <el-form-item prop="project.estimateType" label="评价类型">
            <el-select v-model="state.formData.project.estimateType" class="m-2" size="large" placeholder="请选择" style="width: 100%" >
              <el-option
                  v-for="item in state.estimateTypeList"
                  :key="item.id"
                  :label="item.label"
                  :value="item.id"
              />
            </el-select>
          </el-form-item>
        </el-col>
        <el-col :span="6">
          <el-form-item prop="project.code" label="项目编号">
            <el-input
                v-model="state.formData.project.code"
                size="large"
                placeholder="请输入项目编号"
            >
            </el-input>
          </el-form-item>
        </el-col>
        <el-col :span="6">
          <el-form-item prop="project.invest" label="项目投资金额">
            <el-input
                v-model="state.formData.project.invest"
                size="large"
                placeholder="请输入项目投资金额"
            >
              <template #append>万元</template>
            </el-input>
          </el-form-item>
        </el-col>
        <el-col :span="6">
          <el-form-item prop="project.area" label="所属区域">
            <el-cascader
                v-model="state.formData.project.area"
                :options="state.addressList"
                :props="props"
                @change="handleChange"
                style="width: 100%"
                size="large"
            />
          </el-form-item>
        </el-col>
      </el-row>
      <el-row el-row :gutter="30">
        <el-col :span="6">
          <el-form-item prop="project.business" label="业务范围">
            <el-select v-model="state.formData.project.business" class="m-2" size="large" placeholder="请选择" style="width: 100%" >
              <el-option
                  v-for="item in state.businessList"
                  :key="item.id"
                  :label="item.label"
                  :value="item.id"
              />
            </el-select>
          </el-form-item>
        </el-col>
      </el-row>
      <el-form-item prop="project.introduction" label="基本概括">
        <el-input
            v-model="state.formData.project.introduction"
            :autosize="{ minRows: 6 }"
            maxlength="500"
            show-word-limit
            type="textarea">
        </el-input>
      </el-form-item>
      <el-form-item prop="riskCharacter" label="行业风险特性">
        <el-input
            v-model="state.formData.riskCharacter"
            :autosize="{ minRows: 6 }"
            maxlength="500"
            show-word-limit
            type="textarea">
        </el-input>
      </el-form-item>
      <el-form-item prop="surroundings" label="周边环境">
        <el-input
            v-model="state.formData.surroundings"
            :autosize="{ minRows: 6 }"
            maxlength="500"
            show-word-limit
            type="textarea">
        </el-input>
      </el-form-item>
      <el-form-item prop="equipment" label="主要生产装置">
        <el-input
            v-model="state.formData.equipment"
            :autosize="{ minRows: 6 }"
            maxlength="500"
            show-word-limit
            type="textarea">
        </el-input>
      </el-form-item>
      <el-form-item prop="technology" label="生产工艺概况">
        <el-input
            v-model="state.formData.technology"
            :autosize="{ minRows: 6 }"
            maxlength="500"
            show-word-limit
            type="textarea">
        </el-input>
      </el-form-item>
      <el-table  :data="state.tableData" :border="true" style="margin: 20px 0">
        <el-table-column label="序号" width="60" align="center" type="index"></el-table-column>
        <el-table-column label="内容" prop="content" header-align="center" :show-overflow-tooltip="true"/>
        <el-table-column label="选择" header-align="center" class-name="small-padding fixed-width" width="175">
          <template #default="scope">
            <el-radio-group v-model="scope.row.status" >
              <el-radio :label="1">{{scope.row.id ==='6' ? '可行': '是'}}</el-radio>
              <el-radio :label="0">{{scope.row.id ==='6' ? '不可行': '否'}}</el-radio>
            </el-radio-group>
          </template>
        </el-table-column>
      </el-table>
      <el-row :gutter="30">
        <el-col :span="6">
          <el-form-item prop="estimateDate" label="评估日期">
            <el-date-picker
                style="width: 100%"
                v-model="state.formData.estimateDate"
                type="date"
                value-format="YYYY-MM-DD 00:00:00"
                placeholder="选择日期"
                size="large"
            />
          </el-form-item>
        </el-col>
        <el-col :span="6">
          <el-form-item prop="techOpinion" label="技术负责人意见">
            <el-input
                v-model="state.formData.techOpinion"
                size="large"
                maxlength="30"
                show-word-limit
                placeholder="技术负责人意见"
            >
            </el-input>
          </el-form-item>
        </el-col>
        <el-col :span="6">
          <el-form-item prop="riskOpinion" label="风险评估人意见">
            <el-input
                v-model="state.formData.riskOpinion"
                size="large"
                maxlength="30"
                show-word-limit
                placeholder="风险评估人意见"
            >
            </el-input>
          </el-form-item>
        </el-col>
        <el-col :span="6">
          <el-form-item prop="agencyOpinon" label="机构评价负责人意见">
            <el-input
                maxlength="30"
                show-word-limit
                v-model="state.formData.agencyOpinon"
                size="large"
                placeholder="机构评价负责人意见"
            >
            </el-input>
          </el-form-item>
        </el-col>
      </el-row>

    </el-form>
  </div>

</template>
<script setup>

import {defineEmits, onMounted, reactive, ref} from "vue";
import {getDictList} from "@/api/backManage/evaluate";
import {ElMessage} from "element-plus";
import {getDict} from "@/api/login";
import {getRegionTree} from "@/api/area";
import {addRisk, editRisk, getRiskDetail} from "@/api/projectManage/riskAnalysis";
import Cookies from "js-cookie";
const emit = defineEmits(["getNextStatus"]);

const isAmin = ref(false)
const formRef = ref();
onMounted(() => {
  const userInfo = JSON.parse(Cookies.get('userInfo'))
  if(userInfo.identity === 0){
    isAmin.value = true;
  }
  getRiskList();
  getBusinessList();
  getArea();
});
const state = reactive({
  formData: {
    project: {
      id: '',
      name: '',
      client: '',
      creditCode: '',
      address:'',
      estimateType: null,
      code: '',
      invest: '',
      area: [],
      district: '',
      city: '',
      province: '',
      business: '',
      introduction: '',
    },
    id: '',
    riskCharacter: '',
    surroundings: '',
    equipment: '',
    technology: '',
    isInBusiness: true,
    isSatisfyNeed: true,
    isNeedExpert: true,
    isFinishReport: true,
    isAcceptChargess: true,
    isFeasibility: true,
    estimateDate: '',
    techOpinion: '',
    riskOpinion: '',
    agencyOpinon: ''
  },
  rules: {
    "project.name": [{required: true, message: '请填写项目名称', trigger: 'blur'}],
    "project.client": [{required: true, message: '请填写委托单位', trigger: 'blur'}],
    "project.creditCode": [{required: true, message: '请填写委托单位统一社会信用代码', trigger: 'blur'}],
    "project.estimateType": [{required: true, message: '请选择评价类型', trigger: 'blur'}],
    "project.address": [{required: true, message: '请填写详细地址', trigger: 'blur'}],
    "project.invest": [{required: true, message: '请填写投资金额', trigger: 'blur'}],
    "project.area": [{required: true, message: '请选择所属区域', trigger: 'blur'}],
    "project.business": [{required: true, message: '请选择业务范围', trigger: 'blur'}],
    "project.introduction": [{required: true, message: '请填写基本概况', trigger: 'blur'}],
    riskCharacter: [{required: true, message: '请填写行业风险特性', trigger: 'blur'}],
    surroundings: [{required: true, message: '请填写周边环境', trigger: 'blur'}],
    estimateDate: [{required: true, message: '请选择评估日期', trigger: 'blur'}],
    techOpinion: [{required: true, message: '请填写技术负责人意见', trigger: 'blur'}],
    riskOpinion: [{required: true, message: '请填写风险评估人意见', trigger: 'blur'}],
    agencyOpinon: [{required: true, message: '请填写机构评价负责人意见', trigger: 'blur'}],
  },
  estimateTypeList: [],
  addressList: [],
  businessList: [],
  tableData: [
    {
      id: '1',
      content: '评价项目是否在本机构资质业务范围内',
      status: 1
    },
    {
      id: '2',
      content: '评价人员专业构成是否满足评价项目需要',
      status: 1
    },
    {
      id: '3',
      content: '是否需要聘请相关专业的技术专家',
      status: 1
    },
    {
      id: '4',
      content: '是否能在约定的时间内完成评价报告',
      status: 1
    },
    {
      id: '5',
      content: '评价费用是否在本机构所接受的范围内',
      status: 1
    },
    {
      id: '6',
      content: '项目的可行性（风险分析结论）',
      status: 1
    },
  ]
})
const props = {
  expandTrigger: 'hover',
  value: 'name',
  label: 'name'
}


const getRiskList = async () => {
  const res = await getDictList({dictType: "sys_assess_type"});
  if(res.code === 200){
    state.estimateTypeList = res.data.list
  }else{
    ElMessage.warning(res.message)
  }
}
const getBusinessList = async () => {
  const res = await getDict({dictType: 'sys_business_scope'})
  if(res.code === 200){
    state.businessList = res.data
  }else{
    ElMessage.warning(res.message)
  }
}
const getArea = async ()=>{
  const type = 1
  const res = await getRegionTree({name: '',parentId: null,regionType: type})
  if(res.code == 200){
    state.addressList = res.data
  }else{
    ElMessage.warning(res.message)
  }
}
const riskOpen = async (type,val) => {
  console.log("type",type,val)
  if(type === 'detail' || type === 'edit' ){
    const res = await getRiskDetail({projectId: val});
    if(res.code == 200){
      state.formData = res.data;
      state.formData.project.business = parseInt(res.data.project.business);
      if(res.data.project.province == '北京市' || res.data.project.province == '天津市' || res.data.project.province == '上海市' || res.data.project.province == '重庆市' || res.data.project.province == '香港特别行政区' || res.data.project.province == '澳门特别行政区'){
        state.formData.project.area = [res.data.project.province]
      }else{
        state.formData.project.area = [res.data.project.province,res.data.project.city];
      }
      state.tableData[0].status = res.data.isInBusiness ? 1 : 0;
      state.tableData[1].status = res.data.isSatisfyNeed ? 1 : 0;
      state.tableData[2].status = res.data.isNeedExpert ? 1 : 0;
      state.tableData[3].status = res.data.isFinishReport ? 1 : 0;
      state.tableData[4].status = res.data.isAcceptChargess ? 1 : 0;
      state.tableData[5].status = res.data.isFeasibility ? 1 : 0;
    }else {
      ElMessage.warning(res.message)
    }
  }
  if(type === 'add' || type === 'clickEdit') {
    const valid = await formRef.value.validate();
    if(valid){
      if (isAmin.value) {
        ElMessage.warning("当前用户暂无权限");
        return;
      }
      if(type === 'add'){
        const {id, ...data} = JSON.parse(JSON.stringify(state.formData))
        delete data.project.area;
        delete data.project.id;
        if(data.project.province == '北京市' || data.project.province == '天津市' || data.project.province == '上海市' || data.project.province == '重庆市' || data.project.province == '香港特别行政区' || data.project.province == '澳门特别行政区'){
          data.project.city = data.project.province
        }
        data.isInBusiness = state.tableData[0].status === 1;
        data.isSatisfyNeed = state.tableData[1].status === 1;
        data.isNeedExpert = state.tableData[2].status === 1;
        data.isFinishReport = state.tableData[3].status === 1;
        data.isAcceptChargess = state.tableData[4].status === 1;
        data.isFeasibility = state.tableData[5].status === 1;
        const res = await addRisk(data);
        if (res.code == 200) {
          ElMessage.success('保存成功')
          formRef.value.clearValidate();
          emit('getNextStatus', res.data);

        } else {
          ElMessage.warning(res.message)
        }
      }else if(type === 'clickEdit'){
        const { ...data} = JSON.parse(JSON.stringify(state.formData))
        data.id = val;
        data.project.id = val;
        if(data.project.province == '北京市' || data.project.province == '天津市' || data.project.province == '上海市' || data.project.province == '重庆市' || data.project.province == '香港特别行政区' || data.project.province == '澳门特别行政区'){
          data.project.city = data.project.province
        }
        delete data.project.area;
        data.isInBusiness = state.tableData[0].status === 1
        data.isSatisfyNeed = state.tableData[1].status === 1
        data.isNeedExpert = state.tableData[2].status === 1
        data.isFinishReport = state.tableData[3].status === 1
        data.isAcceptChargess = state.tableData[4].status === 1
        data.isFeasibility = state.tableData[5].status === 1
        const res = await editRisk(data);
        if (res.code == 200) {
          ElMessage.success('变更成功')
          formRef.value.clearValidate();
          // emit('getNextStatus', data.project.id);
        } else {
          ElMessage.warning(res.message)
        }
      }
    }
  }
}

const handleChange = (value) => {
  // if(state.registerForm.agency.attribute == 0){
  //   state.registerForm.agency.province = '新疆维吾尔自治区'
  //   state.registerForm.agency.city = value[0]?value[0]:''
  //   state.registerForm.agency.district  = value[1]?value[1]:''
  // }else{
    state.formData.project.province = value[0]?value[0]:''
    state.formData.project.city = value[1]?value[1]:''
    state.formData.project.district  = value[2]?value[2]:''
  // }
}



defineExpose({
  riskOpen
});


</script>
<style scoped lang="scss">
.riskBox{
  :deep(.el-form .el-form-item__label) {
    font-size: 15px;
  }
}

</style>
